Python Source Extractor
=======================

This is the Python Source Extractor (PySE) for radio astronomical images.

This project was formerly part of the Transient Detection Pipeline:

https://github.com/transientskp/tkp/


Installation
------------

PySE available on pypi::

    $ pip install radio-pyse

PySE is compatible with Python 3.10 or up.


License
-------

PySE is released under the BSD-2 license.


Authors
-------

The list of authors, sorted by the number of commits:

- Hanno Spreeuw
- John Swinbank
- Gijs Molenaar
- Tim Staley
- Evert Rol
- John Sanders
- Bart Scheers
- Mark Kuiack


Developer information
---------------------

.. image:: https://github.com/transientskp/pyse/actions/workflows/python-tests.yml/badge.svg
   :target: https://github.com/transientskp/pyse/actions/workflows/python-tests.yml
